=====================================
Sources of Unit String Definitions
=====================================

The string processing tests and strings supported came from a number of different sources.
